@@ -53,7 +53,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._avatar_url)
-        return self._NoneIfNotSet(self._avatar_url)
+        return self._avatar_url.value
 
     @property
     def bio(self):
@@ -61,7 +61,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._bio)
-        return self._NoneIfNotSet(self._bio)
+        return self._bio.value
 
     @property
     def blog(self):
@@ -69,7 +69,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._blog)
-        return self._NoneIfNotSet(self._blog)
+        return self._blog.value
 
     @property
     def collaborators(self):
@@ -77,7 +77,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: integer
         """
         self._completeIfNotSet(self._collaborators)
-        return self._NoneIfNotSet(self._collaborators)
+        return self._collaborators.value
 
     @property
     def company(self):
@@ -85,7 +85,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._company)
-        return self._NoneIfNotSet(self._company)
+        return self._company.value
 
     @property
     def created_at(self):
@@ -93,7 +93,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: datetime.datetime
         """
         self._completeIfNotSet(self._created_at)
-        return self._NoneIfNotSet(self._created_at)
+        return self._created_at.value
 
     @property
     def disk_usage(self):
@@ -101,7 +101,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: integer
         """
         self._completeIfNotSet(self._disk_usage)
-        return self._NoneIfNotSet(self._disk_usage)
+        return self._disk_usage.value
 
     @property
     def email(self):
@@ -109,7 +109,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._email)
-        return self._NoneIfNotSet(self._email)
+        return self._email.value
 
     @property
     def events_url(self):
@@ -117,7 +117,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._events_url)
-        return self._NoneIfNotSet(self._events_url)
+        return self._events_url.value
 
     @property
     def followers(self):
@@ -125,7 +125,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: integer
         """
         self._completeIfNotSet(self._followers)
-        return self._NoneIfNotSet(self._followers)
+        return self._followers.value
 
     @property
     def followers_url(self):
@@ -133,7 +133,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._followers_url)
-        return self._NoneIfNotSet(self._followers_url)
+        return self._followers_url.value
 
     @property
     def following(self):
@@ -141,7 +141,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: integer
         """
         self._completeIfNotSet(self._following)
-        return self._NoneIfNotSet(self._following)
+        return self._following.value
 
     @property
     def following_url(self):
@@ -149,7 +149,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._following_url)
-        return self._NoneIfNotSet(self._following_url)
+        return self._following_url.value
 
     @property
     def gists_url(self):
@@ -157,7 +157,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._gists_url)
-        return self._NoneIfNotSet(self._gists_url)
+        return self._gists_url.value
 
     @property
     def gravatar_id(self):
@@ -165,7 +165,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._gravatar_id)
-        return self._NoneIfNotSet(self._gravatar_id)
+        return self._gravatar_id.value
 
     @property
     def hireable(self):
@@ -173,7 +173,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: bool
         """
         self._completeIfNotSet(self._hireable)
-        return self._NoneIfNotSet(self._hireable)
+        return self._hireable.value
 
     @property
     def html_url(self):
@@ -181,7 +181,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._html_url)
-        return self._NoneIfNotSet(self._html_url)
+        return self._html_url.value
 
     @property
     def id(self):
@@ -189,7 +189,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: integer
         """
         self._completeIfNotSet(self._id)
-        return self._NoneIfNotSet(self._id)
+        return self._id.value
 
     @property
     def location(self):
@@ -197,7 +197,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._location)
-        return self._NoneIfNotSet(self._location)
+        return self._location.value
 
     @property
     def login(self):
@@ -205,7 +205,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._login)
-        return self._NoneIfNotSet(self._login)
+        return self._login.value
 
     @property
     def name(self):
@@ -213,7 +213,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._name)
-        return self._NoneIfNotSet(self._name)
+        return self._name.value
 
     @property
     def organizations_url(self):
@@ -221,7 +221,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._organizations_url)
-        return self._NoneIfNotSet(self._organizations_url)
+        return self._organizations_url.value
 
     @property
     def owned_private_repos(self):
@@ -229,7 +229,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: integer
         """
         self._completeIfNotSet(self._owned_private_repos)
-        return self._NoneIfNotSet(self._owned_private_repos)
+        return self._owned_private_repos.value
 
     @property
     def plan(self):
@@ -237,7 +237,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: :class:`github.Plan.Plan`
         """
         self._completeIfNotSet(self._plan)
-        return self._NoneIfNotSet(self._plan)
+        return self._plan.value
 
     @property
     def private_gists(self):
@@ -245,7 +245,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: integer
         """
         self._completeIfNotSet(self._private_gists)
-        return self._NoneIfNotSet(self._private_gists)
+        return self._private_gists.value
 
     @property
     def public_gists(self):
@@ -253,7 +253,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: integer
         """
         self._completeIfNotSet(self._public_gists)
-        return self._NoneIfNotSet(self._public_gists)
+        return self._public_gists.value
 
     @property
     def public_repos(self):
@@ -261,7 +261,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: integer
         """
         self._completeIfNotSet(self._public_repos)
-        return self._NoneIfNotSet(self._public_repos)
+        return self._public_repos.value
 
     @property
     def received_events_url(self):
@@ -269,7 +269,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._received_events_url)
-        return self._NoneIfNotSet(self._received_events_url)
+        return self._received_events_url.value
 
     @property
     def repos_url(self):
@@ -277,7 +277,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._repos_url)
-        return self._NoneIfNotSet(self._repos_url)
+        return self._repos_url.value
 
     @property
     def site_admin(self):
@@ -285,7 +285,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: bool
         """
         self._completeIfNotSet(self._site_admin)
-        return self._NoneIfNotSet(self._site_admin)
+        return self._site_admin.value
 
     @property
     def starred_url(self):
@@ -293,7 +293,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._starred_url)
-        return self._NoneIfNotSet(self._starred_url)
+        return self._starred_url.value
 
     @property
     def subscriptions_url(self):
@@ -301,7 +301,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._subscriptions_url)
-        return self._NoneIfNotSet(self._subscriptions_url)
+        return self._subscriptions_url.value
 
     @property
     def total_private_repos(self):
@@ -309,7 +309,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: integer
         """
         self._completeIfNotSet(self._total_private_repos)
-        return self._NoneIfNotSet(self._total_private_repos)
+        return self._total_private_repos.value
 
     @property
     def type(self):
@@ -317,7 +317,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._type)
-        return self._NoneIfNotSet(self._type)
+        return self._type.value
 
     @property
     def updated_at(self):
@@ -325,7 +325,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: datetime.datetime
         """
         self._completeIfNotSet(self._updated_at)
-        return self._NoneIfNotSet(self._updated_at)
+        return self._updated_at.value
 
     @property
     def url(self):
@@ -333,7 +333,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._url)
-        return self._NoneIfNotSet(self._url)
+        return self._url.value
 
     def add_to_emails(self, *emails):
         """
@@ -900,6 +900,18 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
             None
         )
 
+    def get_teams(self):
+        """
+        :calls: `GET /user/teams <http://developer.github.com/v3/orgs/teams>`_
+        :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Team.Team`
+        """
+        return github.PaginatedList.PaginatedList(
+            github.Team.Team,
+            self._requester,
+            "/user/teams",
+            None
+        )
+
     def get_watched(self):
         """
         :calls: `GET /user/watched <http://developer.github.com/v3/activity/starring>`_
@@ -1066,110 +1078,74 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
 
     def _useAttributes(self, attributes):
         if "avatar_url" in attributes:  # pragma no branch
-            assert attributes["avatar_url"] is None or isinstance(attributes["avatar_url"], (str, unicode)), attributes["avatar_url"]
-            self._avatar_url = attributes["avatar_url"]
+            self._avatar_url = self._makeStringAttribute(attributes["avatar_url"])
         if "bio" in attributes:  # pragma no branch
-            assert attributes["bio"] is None or isinstance(attributes["bio"], (str, unicode)), attributes["bio"]
-            self._bio = attributes["bio"]
+            self._bio = self._makeStringAttribute(attributes["bio"])
         if "blog" in attributes:  # pragma no branch
-            assert attributes["blog"] is None or isinstance(attributes["blog"], (str, unicode)), attributes["blog"]
-            self._blog = attributes["blog"]
+            self._blog = self._makeStringAttribute(attributes["blog"])
         if "collaborators" in attributes:  # pragma no branch
-            assert attributes["collaborators"] is None or isinstance(attributes["collaborators"], (int, long)), attributes["collaborators"]
-            self._collaborators = attributes["collaborators"]
+            self._collaborators = self._makeIntAttribute(attributes["collaborators"])
         if "company" in attributes:  # pragma no branch
-            assert attributes["company"] is None or isinstance(attributes["company"], (str, unicode)), attributes["company"]
-            self._company = attributes["company"]
+            self._company = self._makeStringAttribute(attributes["company"])
         if "created_at" in attributes:  # pragma no branch
-            assert attributes["created_at"] is None or isinstance(attributes["created_at"], (str, unicode)), attributes["created_at"]
-            self._created_at = self._parseDatetime(attributes["created_at"])
+            self._created_at = self._makeDatetimeAttribute(attributes["created_at"])
         if "disk_usage" in attributes:  # pragma no branch
-            assert attributes["disk_usage"] is None or isinstance(attributes["disk_usage"], (int, long)), attributes["disk_usage"]
-            self._disk_usage = attributes["disk_usage"]
+            self._disk_usage = self._makeIntAttribute(attributes["disk_usage"])
         if "email" in attributes:  # pragma no branch
-            assert attributes["email"] is None or isinstance(attributes["email"], (str, unicode)), attributes["email"]
-            self._email = attributes["email"]
+            self._email = self._makeStringAttribute(attributes["email"])
         if "events_url" in attributes:  # pragma no branch
-            assert attributes["events_url"] is None or isinstance(attributes["events_url"], (str, unicode)), attributes["events_url"]
-            self._events_url = attributes["events_url"]
+            self._events_url = self._makeStringAttribute(attributes["events_url"])
         if "followers" in attributes:  # pragma no branch
-            assert attributes["followers"] is None or isinstance(attributes["followers"], (int, long)), attributes["followers"]
-            self._followers = attributes["followers"]
+            self._followers = self._makeIntAttribute(attributes["followers"])
         if "followers_url" in attributes:  # pragma no branch
-            assert attributes["followers_url"] is None or isinstance(attributes["followers_url"], (str, unicode)), attributes["followers_url"]
-            self._followers_url = attributes["followers_url"]
+            self._followers_url = self._makeStringAttribute(attributes["followers_url"])
         if "following" in attributes:  # pragma no branch
-            assert attributes["following"] is None or isinstance(attributes["following"], (int, long)), attributes["following"]
-            self._following = attributes["following"]
+            self._following = self._makeIntAttribute(attributes["following"])
         if "following_url" in attributes:  # pragma no branch
-            assert attributes["following_url"] is None or isinstance(attributes["following_url"], (str, unicode)), attributes["following_url"]
-            self._following_url = attributes["following_url"]
+            self._following_url = self._makeStringAttribute(attributes["following_url"])
         if "gists_url" in attributes:  # pragma no branch
-            assert attributes["gists_url"] is None or isinstance(attributes["gists_url"], (str, unicode)), attributes["gists_url"]
-            self._gists_url = attributes["gists_url"]
+            self._gists_url = self._makeStringAttribute(attributes["gists_url"])
         if "gravatar_id" in attributes:  # pragma no branch
-            assert attributes["gravatar_id"] is None or isinstance(attributes["gravatar_id"], (str, unicode)), attributes["gravatar_id"]
-            self._gravatar_id = attributes["gravatar_id"]
+            self._gravatar_id = self._makeStringAttribute(attributes["gravatar_id"])
         if "hireable" in attributes:  # pragma no branch
-            assert attributes["hireable"] is None or isinstance(attributes["hireable"], bool), attributes["hireable"]
-            self._hireable = attributes["hireable"]
+            self._hireable = self._makeBoolAttribute(attributes["hireable"])
         if "html_url" in attributes:  # pragma no branch
-            assert attributes["html_url"] is None or isinstance(attributes["html_url"], (str, unicode)), attributes["html_url"]
-            self._html_url = attributes["html_url"]
+            self._html_url = self._makeStringAttribute(attributes["html_url"])
         if "id" in attributes:  # pragma no branch
-            assert attributes["id"] is None or isinstance(attributes["id"], (int, long)), attributes["id"]
-            self._id = attributes["id"]
+            self._id = self._makeIntAttribute(attributes["id"])
         if "location" in attributes:  # pragma no branch
-            assert attributes["location"] is None or isinstance(attributes["location"], (str, unicode)), attributes["location"]
-            self._location = attributes["location"]
+            self._location = self._makeStringAttribute(attributes["location"])
         if "login" in attributes:  # pragma no branch
-            assert attributes["login"] is None or isinstance(attributes["login"], (str, unicode)), attributes["login"]
-            self._login = attributes["login"]
+            self._login = self._makeStringAttribute(attributes["login"])
         if "name" in attributes:  # pragma no branch
-            assert attributes["name"] is None or isinstance(attributes["name"], (str, unicode)), attributes["name"]
-            self._name = attributes["name"]
+            self._name = self._makeStringAttribute(attributes["name"])
         if "organizations_url" in attributes:  # pragma no branch
-            assert attributes["organizations_url"] is None or isinstance(attributes["organizations_url"], (str, unicode)), attributes["organizations_url"]
-            self._organizations_url = attributes["organizations_url"]
+            self._organizations_url = self._makeStringAttribute(attributes["organizations_url"])
         if "owned_private_repos" in attributes:  # pragma no branch
-            assert attributes["owned_private_repos"] is None or isinstance(attributes["owned_private_repos"], (int, long)), attributes["owned_private_repos"]
-            self._owned_private_repos = attributes["owned_private_repos"]
+            self._owned_private_repos = self._makeIntAttribute(attributes["owned_private_repos"])
         if "plan" in attributes:  # pragma no branch
-            assert attributes["plan"] is None or isinstance(attributes["plan"], dict), attributes["plan"]
-            self._plan = None if attributes["plan"] is None else github.Plan.Plan(self._requester, self._headers, attributes["plan"], completed=False)
+            self._plan = self._makeClassAttribute(github.Plan.Plan, attributes["plan"])
         if "private_gists" in attributes:  # pragma no branch
-            assert attributes["private_gists"] is None or isinstance(attributes["private_gists"], (int, long)), attributes["private_gists"]
-            self._private_gists = attributes["private_gists"]
+            self._private_gists = self._makeIntAttribute(attributes["private_gists"])
         if "public_gists" in attributes:  # pragma no branch
-            assert attributes["public_gists"] is None or isinstance(attributes["public_gists"], (int, long)), attributes["public_gists"]
-            self._public_gists = attributes["public_gists"]
+            self._public_gists = self._makeIntAttribute(attributes["public_gists"])
         if "public_repos" in attributes:  # pragma no branch
-            assert attributes["public_repos"] is None or isinstance(attributes["public_repos"], (int, long)), attributes["public_repos"]
-            self._public_repos = attributes["public_repos"]
+            self._public_repos = self._makeIntAttribute(attributes["public_repos"])
         if "received_events_url" in attributes:  # pragma no branch
-            assert attributes["received_events_url"] is None or isinstance(attributes["received_events_url"], (str, unicode)), attributes["received_events_url"]
-            self._received_events_url = attributes["received_events_url"]
+            self._received_events_url = self._makeStringAttribute(attributes["received_events_url"])
         if "repos_url" in attributes:  # pragma no branch
-            assert attributes["repos_url"] is None or isinstance(attributes["repos_url"], (str, unicode)), attributes["repos_url"]
-            self._repos_url = attributes["repos_url"]
+            self._repos_url = self._makeStringAttribute(attributes["repos_url"])
         if "site_admin" in attributes:  # pragma no branch
-            assert attributes["site_admin"] is None or isinstance(attributes["site_admin"], bool), attributes["site_admin"]
-            self._site_admin = attributes["site_admin"]
+            self._site_admin = self._makeBoolAttribute(attributes["site_admin"])
         if "starred_url" in attributes:  # pragma no branch
-            assert attributes["starred_url"] is None or isinstance(attributes["starred_url"], (str, unicode)), attributes["starred_url"]
-            self._starred_url = attributes["starred_url"]
+            self._starred_url = self._makeStringAttribute(attributes["starred_url"])
         if "subscriptions_url" in attributes:  # pragma no branch
-            assert attributes["subscriptions_url"] is None or isinstance(attributes["subscriptions_url"], (str, unicode)), attributes["subscriptions_url"]
-            self._subscriptions_url = attributes["subscriptions_url"]
+            self._subscriptions_url = self._makeStringAttribute(attributes["subscriptions_url"])
         if "total_private_repos" in attributes:  # pragma no branch
-            assert attributes["total_private_repos"] is None or isinstance(attributes["total_private_repos"], (int, long)), attributes["total_private_repos"]
-            self._total_private_repos = attributes["total_private_repos"]
+            self._total_private_repos = self._makeIntAttribute(attributes["total_private_repos"])
         if "type" in attributes:  # pragma no branch
-            assert attributes["type"] is None or isinstance(attributes["type"], (str, unicode)), attributes["type"]
-            self._type = attributes["type"]
+            self._type = self._makeStringAttribute(attributes["type"])
         if "updated_at" in attributes:  # pragma no branch
-            assert attributes["updated_at"] is None or isinstance(attributes["updated_at"], (str, unicode)), attributes["updated_at"]
-            self._updated_at = self._parseDatetime(attributes["updated_at"])
+            self._updated_at = self._makeDatetimeAttribute(attributes["updated_at"])
         if "url" in attributes:  # pragma no branch
-            assert attributes["url"] is None or isinstance(attributes["url"], (str, unicode)), attributes["url"]
-            self._url = attributes["url"]
+            self._url = self._makeStringAttribute(attributes["url"])
