@@ -42,7 +42,7 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._body)
-        return self._NoneIfNotSet(self._body)
+        return self._body.value
 
     @property
     def commit_id(self):
@@ -50,7 +50,7 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._commit_id)
-        return self._NoneIfNotSet(self._commit_id)
+        return self._commit_id.value
 
     @property
     def created_at(self):
@@ -58,7 +58,7 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
         :type: datetime.datetime
         """
         self._completeIfNotSet(self._created_at)
-        return self._NoneIfNotSet(self._created_at)
+        return self._created_at.value
 
     @property
     def diff_hunk(self):
@@ -66,7 +66,7 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._diff_hunk)
-        return self._NoneIfNotSet(self._diff_hunk)
+        return self._diff_hunk.value
 
     @property
     def id(self):
@@ -74,7 +74,7 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
         :type: integer
         """
         self._completeIfNotSet(self._id)
-        return self._NoneIfNotSet(self._id)
+        return self._id.value
 
     @property
     def original_commit_id(self):
@@ -82,7 +82,7 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._original_commit_id)
-        return self._NoneIfNotSet(self._original_commit_id)
+        return self._original_commit_id.value
 
     @property
     def original_position(self):
@@ -90,7 +90,7 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
         :type: integer
         """
         self._completeIfNotSet(self._original_position)
-        return self._NoneIfNotSet(self._original_position)
+        return self._original_position.value
 
     @property
     def path(self):
@@ -98,7 +98,7 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._path)
-        return self._NoneIfNotSet(self._path)
+        return self._path.value
 
     @property
     def position(self):
@@ -106,7 +106,7 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
         :type: integer
         """
         self._completeIfNotSet(self._position)
-        return self._NoneIfNotSet(self._position)
+        return self._position.value
 
     @property
     def pull_request_url(self):
@@ -114,7 +114,7 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._pull_request_url)
-        return self._NoneIfNotSet(self._pull_request_url)
+        return self._pull_request_url.value
 
     @property
     def updated_at(self):
@@ -122,7 +122,7 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
         :type: datetime.datetime
         """
         self._completeIfNotSet(self._updated_at)
-        return self._NoneIfNotSet(self._updated_at)
+        return self._updated_at.value
 
     @property
     def url(self):
@@ -130,7 +130,7 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._url)
-        return self._NoneIfNotSet(self._url)
+        return self._url.value
 
     @property
     def html_url(self):
@@ -138,7 +138,7 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._html_url)
-        return self._NoneIfNotSet(self._html_url)
+        return self._html_url.value
 
     @property
     def user(self):
@@ -146,7 +146,7 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
         :type: :class:`github.NamedUser.NamedUser`
         """
         self._completeIfNotSet(self._user)
-        return self._NoneIfNotSet(self._user)
+        return self._user.value
 
     def delete(self):
         """
@@ -193,44 +193,30 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
 
     def _useAttributes(self, attributes):
         if "body" in attributes:  # pragma no branch
-            assert attributes["body"] is None or isinstance(attributes["body"], (str, unicode)), attributes["body"]
-            self._body = attributes["body"]
+            self._body = self._makeStringAttribute(attributes["body"])
         if "commit_id" in attributes:  # pragma no branch
-            assert attributes["commit_id"] is None or isinstance(attributes["commit_id"], (str, unicode)), attributes["commit_id"]
-            self._commit_id = attributes["commit_id"]
+            self._commit_id = self._makeStringAttribute(attributes["commit_id"])
         if "created_at" in attributes:  # pragma no branch
-            assert attributes["created_at"] is None or isinstance(attributes["created_at"], (str, unicode)), attributes["created_at"]
-            self._created_at = self._parseDatetime(attributes["created_at"])
+            self._created_at = self._makeDatetimeAttribute(attributes["created_at"])
         if "diff_hunk" in attributes:  # pragma no branch
-            assert attributes["diff_hunk"] is None or isinstance(attributes["diff_hunk"], (str, unicode)), attributes["diff_hunk"]
-            self._diff_hunk = attributes["diff_hunk"]
+            self._diff_hunk = self._makeStringAttribute(attributes["diff_hunk"])
         if "id" in attributes:  # pragma no branch
-            assert attributes["id"] is None or isinstance(attributes["id"], (int, long)), attributes["id"]
-            self._id = attributes["id"]
+            self._id = self._makeIntAttribute(attributes["id"])
         if "original_commit_id" in attributes:  # pragma no branch
-            assert attributes["original_commit_id"] is None or isinstance(attributes["original_commit_id"], (str, unicode)), attributes["original_commit_id"]
-            self._original_commit_id = attributes["original_commit_id"]
+            self._original_commit_id = self._makeStringAttribute(attributes["original_commit_id"])
         if "original_position" in attributes:  # pragma no branch
-            assert attributes["original_position"] is None or isinstance(attributes["original_position"], (int, long)), attributes["original_position"]
-            self._original_position = attributes["original_position"]
+            self._original_position = self._makeIntAttribute(attributes["original_position"])
         if "path" in attributes:  # pragma no branch
-            assert attributes["path"] is None or isinstance(attributes["path"], (str, unicode)), attributes["path"]
-            self._path = attributes["path"]
+            self._path = self._makeStringAttribute(attributes["path"])
         if "position" in attributes:  # pragma no branch
-            assert attributes["position"] is None or isinstance(attributes["position"], (int, long)), attributes["position"]
-            self._position = attributes["position"]
+            self._position = self._makeIntAttribute(attributes["position"])
         if "pull_request_url" in attributes:  # pragma no branch
-            assert attributes["pull_request_url"] is None or isinstance(attributes["pull_request_url"], (str, unicode)), attributes["pull_request_url"]
-            self._pull_request_url = attributes["pull_request_url"]
+            self._pull_request_url = self._makeStringAttribute(attributes["pull_request_url"])
         if "updated_at" in attributes:  # pragma no branch
-            assert attributes["updated_at"] is None or isinstance(attributes["updated_at"], (str, unicode)), attributes["updated_at"]
-            self._updated_at = self._parseDatetime(attributes["updated_at"])
+            self._updated_at = self._makeDatetimeAttribute(attributes["updated_at"])
         if "url" in attributes:  # pragma no branch
-            assert attributes["url"] is None or isinstance(attributes["url"], (str, unicode)), attributes["url"]
-            self._url = attributes["url"]
+            self._url = self._makeStringAttribute(attributes["url"])
         if "html_url" in attributes:  # pragma no branch
-            assert attributes["html_url"] is None or isinstance(attributes["html_url"], (str, unicode)), attributes["html_url"]
-            self._html_url = attributes["html_url"]
+            self._html_url = self._makeStringAttribute(attributes["html_url"])
         if "user" in attributes:  # pragma no branch
-            assert attributes["user"] is None or isinstance(attributes["user"], dict), attributes["user"]
-            self._user = None if attributes["user"] is None else github.NamedUser.NamedUser(self._requester, self._headers, attributes["user"], completed=False)
+            self._user = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["user"])
